parserFwk.pyparsing.Upcase

Package parserFwk :: Module pyparsing :: Class Upcase |
[frames | no frames]

## Type Upcase

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
             TokenConverter --+
                              |
                             Upcase

Converter to upper case all matching tokens.

Method Summary
| `__init__(self, *args)`
| `postParse(self, instring, loc, tokenlist)`
Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `parseImpl`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `preParse`, `resetCache`, `scanString`, `searchString`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net